@@ -47,7 +47,7 @@ Tmediaentry Gdefaultmedia[] = {
 };
 #endif
 
-Tmyentry Gtypecdaudio[] = {
+static Tmyentry Gtypecdaudio[] = {
   { "1260", N_("21 min"), FALSE },
   { "1380", N_("23 min"), FALSE },
   { "4440", N_("74 min"), FALSE },
@@ -58,7 +58,7 @@ Tmyentry Gtypecdaudio[] = {
   { NULL }
 };
 
-Tmyentry Gtypecddata[] = {
+static Tmyentry Gtypecddata[] = {
   { "180", N_("180 mb"), FALSE },
   { "202", N_("202 mb"), FALSE },
   { "650", N_("650 mb"), FALSE },
@@ -69,13 +69,13 @@ Tmyentry Gtypecddata[] = {
   { NULL }
 };
 
-Tmyentry Gtypeunit[] = {
+static Tmyentry Gtypeunit[] = {
   { "kb", N_("kb"), TRUE },
   { "mb", N_("mb"), FALSE },
   { "gb", N_("gb"), FALSE },
 };
 
-Tmyentry Gmodburn[] = {
+static Tmyentry Gmodburn[] = {
     { "dao", N_("Disk At Once - DAO (default)"), TRUE },
     { "tao", N_("Track At Once  - TAO"), FALSE },
     { "raw96r", N_("RAW writing - raw96r"), FALSE },
@@ -84,24 +84,21 @@ Tmyentry Gmodburn[] = {
     { NULL }
   };
 
-Tmyentry Gisolevel[] = {
+static Tmyentry Gisolevel[] = {
   { "1", N_("ISO 9660 level 1"), FALSE },
   { "2", N_("ISO 9660 level 2 (default)"), TRUE },
   { "3", N_("ISO 9660 level 3"), FALSE },
   { NULL }
 };
 
-Tmyentry Gformatcd[] = {
-    { "mode1", N_("CD-Rom Mode 1 (default)"), TRUE},
+static Tmyentry Gformatcd[] = {
+    { "data", N_("CD-Rom Mode 1 (default)"), TRUE},
     { "mode2", N_("CD-Rom Mode 2"), FALSE },
     { "xa1", N_("CD-Rom XA Mode 1"), FALSE },
     { "xa2", N_("CD-Rom XA Mode 2"), FALSE },
     { NULL }
   };
 
-GdkPixbuf *GDirIcone, *GFileIcone, *GCDIcone, *GAudioIcone, *GCDRWIcone, *GCDpetiteIcone,
-  *GCDRWpetiteIcone, *GpetiteGraver, *GGraver, *GISOpetiteIcone, *GEraseCdrw, *GFileImage;
-
 void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
 {
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
@@ -117,10 +114,9 @@ void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
   if (Ldefspeed && *Ldefspeed) Ldef = atoi(Ldefspeed);
 
   if (Alecident && *Alecident) {
-    Tdrive_info *Lundrive = findlecteur(Alecident);
+    Tdriveinfo *Lundrive = find_drive(Alecident);
 
     Lmaxspeed = Lundrive->vitesse;
-
   }
 
   gtk_list_store_clear(Ldata);
@@ -170,7 +166,7 @@ void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gbo
   for (Lcurentry = Aentry; Lcurentry->label; Lcurentry++) {
     Lident = g_strdup_printf("%s%s", Abasename, Lcurentry->basecode);
     gtk_list_store_append(Ldata, &Liter);
-    gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, Lcurentry->label, -1); 
+    gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, _(Lcurentry->label), -1); 
     g_free(Lident);
     if (Lcurentry->defaut == TRUE) gtk_combo_box_set_active_iter(Acombo, &Liter);
   }
@@ -179,19 +175,22 @@ void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gbo
 void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi)
 {
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
-  gint i;
   gboolean Lpremier = FALSE;
   GtkTreeIter Liter;
+  GSList *Lcur;
+  Tdriveinfo *Ldrive;
+  gint i;
 
   gtk_list_store_clear(Ldata);
-  
-  for (i=0; i < Gnumdrives; i++) {
-    if ((Aquoi & GRAVEUR_ONLY) && (! DRIVE_WRITER(i))) continue;
+ 
+  for (Lcur = Glistdrives, i=0; Lcur; Lcur = g_slist_next(Lcur), i++) { 
+    Ldrive = (Tdriveinfo *)Lcur->data;
+    if ((Aquoi & GRAVEUR_ONLY) && (! DRIVE_WRITER(Ldrive))) continue;
     
     gtk_list_store_append(Ldata, &Liter);
 
-    gtk_list_store_set(Ldata, &Liter, 0, Gldrives[i].dev, 1, 
-      DRIVE_ICONE(i), 2, Gldrives[i].name, 3, i, -1);
+    gtk_list_store_set(Ldata, &Liter, 0, (gchar *)g_slist_nth_data(Ldrive->dev, Ldrive->actuperiph), 1, 
+      DRIVE_ICONE(Ldrive), 2, Ldrive->name, 3, i, -1);
     
     if (Lpremier == FALSE) {      
       Lpremier = TRUE;
@@ -210,13 +209,21 @@ void remplirelistegraveur(GtkTreeView *Aliste)
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_tree_view_get_model(Aliste));
   GtkTreeIter Liter;
   gint i;
+  gchar Llabeldevice[50];
+  GSList *Lcur;
+  Tdriveinfo *Ldrive;
 
   gtk_list_store_clear(Ldata);
-  
-  for (i=0; i < Gnumdrives; i++) {
+
+  for (Lcur = Glistdrives, i=0; Lcur; Lcur = g_slist_next(Lcur), i++) {
+    Ldrive = (Tdriveinfo *)Lcur->data;
+
     gtk_list_store_append(Ldata, &Liter);
-    gtk_list_store_set(Ldata, &Liter, 0, i, 1, DRIVE_ICONE(i), 2, Gldrives[i].dev, 3, 
-          DRIVE_WRITER(i) ? _("CD Recorder") : _("CD Reader"), 4, Gldrives[i].name, -1);
+
+    put_devicelabel(Ldrive, Llabeldevice, sizeof(Llabeldevice)-1);
+    gtk_list_store_set(Ldata, &Liter, 0, i, 1, DRIVE_ICONE(Ldrive), 2,
+          (gchar *)g_slist_nth_data(Ldrive->dev, Ldrive->actuperiph), 3, 
+          Llabeldevice, 4, Ldrive->name, -1);
   }
 }
 
@@ -237,12 +244,31 @@ void remplirelistemedia(GtkTreeView *Aliste)
   }
 }
 #endif
+/* menu popup sur les lecteurs/graveurs */
+GtkMenu *create_gtkpopupmenudevices(GtkWidget *Aliste, GHashTable *Ahash)
+{
+  GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupdevices"));
+  GtkWidget *Litem;
+  GtkTreePath *Lpath = NULL;
+
+  /* on cherche l'object selectionne, on est pas sur qu'il y en ai un car
+   * il n'y a pas forcement de peripheriques de detect */
+  gtk_tree_view_get_cursor(GTK_TREE_VIEW(Aliste), &Lpath, NULL);
+
+  Litem = GTK_WIDGET(g_hash_table_lookup(Ahash, "popupdevices_edit"));
+  gtk_widget_set_sensitive(Litem, Lpath ? TRUE : FALSE);
+  Litem = GTK_WIDGET(g_hash_table_lookup(Ahash, "popupdevices_remove"));
+  gtk_widget_set_sensitive(Litem, Lpath ? TRUE : FALSE);
+
+  if (Lpath) gtk_tree_path_free(Lpath);
+
+  return Lmenu;
+}
+
 /* menu popup sur les pistes audio */
 GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash)
 {
   GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupaudio"));
-  GtkTreeModel *Lmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(Aliste));
-  GtkTreeIter Liter;
   GtkWidget *Litem;
   GtkTreePath *Lpath = NULL;
 
@@ -251,7 +277,7 @@ GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash)
   gtk_tree_view_get_cursor(GTK_TREE_VIEW(Aliste), &Lpath, NULL);
 
   Litem = GTK_WIDGET(g_hash_table_lookup(Ahash, "popupaudio_removetrack"));
-  if (Lpath && gtk_tree_model_get_iter(Lmodel, &Liter, Lpath)) {
+  if (Lpath) {
     gtk_widget_set_sensitive(Litem, TRUE);
   } else {
     gtk_widget_set_sensitive(Litem, FALSE);
@@ -624,13 +650,13 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   prepare_popups(Lxml, Lhash);
   prepare_listeaudio(Ltreeaudio);
   g_signal_connect(G_OBJECT(Ltreeaudio), "button-press-event", G_CALLBACK(gtk_do_eventbuttonpress), Lhash);
-  g_signal_connect(G_OBJECT(Ltreeaudio), "popup-menu", G_CALLBACK(view_popupmenu_addaudio), Lhash);
+  g_signal_connect(G_OBJECT(Ltreeaudio), "popup-menu", G_CALLBACK(key_popupmenu_addaudio), Lhash);
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "btnaddtrack")), "clicked", G_CALLBACK(gtk_audio_addtrack), Lhash);
 
   Ltreedata = GTK_TREE_VIEW(glade_to_hash(Lxml, Lhash, "LISTEDATA"));
   prepare_listedata(Ltreedata);
   g_signal_connect(G_OBJECT(Ltreedata), "button-press-event", G_CALLBACK(gtk_do_eventbuttonpress), Lhash);
-  g_signal_connect(G_OBJECT(Ltreedata), "popup-menu", G_CALLBACK(view_popupmenu_addfile), Lhash);
+  g_signal_connect(G_OBJECT(Ltreedata), "popup-menu", G_CALLBACK(key_popupmenu_addfile), Lhash);
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "btnaddfile")), "clicked", G_CALLBACK(gtk_data_addfile), Lhash);
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "btnadddirectory")), "clicked",
       G_CALLBACK(gtk_data_adddirectory), Lhash);
@@ -658,7 +684,7 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   g_signal_connect(G_OBJECT(Ltreedata), "drag-data-received", G_CALLBACK(data_dnd_data_received),
       Lhash);
 
-  g_signal_connect(G_OBJECT(Lwindow), "delete_event", G_CALLBACK(delete_event_quit), Lhash);
+  g_signal_connect(G_OBJECT(Lwindow), "delete-event", G_CALLBACK(delete_event_quit), Lhash);
 
   /* on restaure la taille et la position que la fenetre avait lors de la derniere utilisation */ 
   restore_main_window_pos(Lwindow); 
@@ -810,22 +836,22 @@ GtkWidget* create_addpisteselection (GtkWindow *AParent)
 
 GtkWidget* create_adddirselection (GtkWindow *AParent)
 {
-  GtkWidget *fileselection1;
-  GtkFileFilter *filterall;
+  GtkWidget *Lfileselection;
+  GtkFileFilter *Lfilterall;
 
   /* filtres pour la selection de fichiers */
-  filterall = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filterall, _("All files (*.*)"));
-  gtk_file_filter_add_pattern(filterall, "*");
-  fileselection1 = gtk_file_chooser_dialog_new(_("Select a directory to add"),
+  Lfilterall = gtk_file_filter_new ();
+  gtk_file_filter_set_name (Lfilterall, _("All files (*.*)"));
+  gtk_file_filter_add_pattern(Lfilterall, "*");
+  Lfileselection = gtk_file_chooser_dialog_new(_("Select a directory to add"),
       AParent, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 
-  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(fileselection1), TRUE);
-  gtk_dialog_set_default_response (GTK_DIALOG (fileselection1), GTK_RESPONSE_ACCEPT);
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (fileselection1), filterall);
+  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(Lfileselection), TRUE);
+  gtk_dialog_set_default_response (GTK_DIALOG (Lfileselection), GTK_RESPONSE_ACCEPT);
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (Lfileselection), Lfilterall);
 
-  return fileselection1;
+  return Lfileselection;
 }
 
 /* boite de dialogue "edition media" */
@@ -860,6 +886,55 @@ GHashTable *addmediaformat(GHashTable *Aparent)
 }
 #endif
 
+/* boite de dialogue "editer un peripherique" */
+GHashTable *create_dialog_edit_device(GtkWidget *Aparent, Tdriveinfo *Adrive)
+{
+  gchar *Ltemplate = PACKAGE_DATA_DIR "/" PACKAGE "/dialog_device.glade";
+  GladeXML *Lxml = glade_xml_new(Ltemplate, NULL,NULL);
+  GtkWidget *Ldialog;
+  GHashTable *Lhash = _hash();
+  GtkComboBox *Lcombobox;
+
+  if (!Lxml) {
+    g_error("Cannot load '%s': %s\n", Ltemplate, g_strerror(errno));
+  }
+
+  Ldialog = glade_xml_get_widget(Lxml, "dialog_device");
+  gtk_window_set_transient_for(GTK_WINDOW(Ldialog), GTK_WINDOW(Aparent));
+  g_hash_table_insert(Lhash, "window", Ldialog);
+
+  gtk_entry_set_text(GTK_ENTRY(glade_to_hash(Lxml, Lhash, "devicename")), Adrive->name);
+  Lcombobox = GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "devicebus"));
+
+  manage_combobox_devicebus(Lcombobox, Adrive);
+
+  return Lhash;
+}
+
+/* boite de dialogue "ajouter un peripherique" */
+GHashTable *create_dialog_add_device(GtkWidget *Aparent)
+{
+  gchar *Ltemplate = PACKAGE_DATA_DIR "/" PACKAGE "/dialog_add_device.glade";
+  GladeXML *Lxml = glade_xml_new(Ltemplate, NULL,NULL);
+  GtkWidget *Ldialog;
+  GHashTable *Lhash = _hash();
+
+  if (!Lxml) {
+    g_error("Cannot load '%s': %s\n", Ltemplate, g_strerror(errno));
+  }
+
+  Ldialog = glade_xml_get_widget(Lxml, "dialog_add_device");
+  gtk_window_set_transient_for(GTK_WINDOW(Ldialog), GTK_WINDOW(Aparent));
+  g_hash_table_insert(Lhash, "window", Ldialog);
+
+  gtk_entry_set_text(GTK_ENTRY(glade_to_hash(Lxml, Lhash, "devicename")), _("New device"));
+  glade_to_hash(Lxml, Lhash, "devicebus");
+
+
+  return Lhash;
+}
+
+
 /* boite de dialogue "a propos de ..." */
 void about_graveman (void)
 {
@@ -899,6 +974,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   gint Lpid = 0, Lpid2 = 0;
   gboolean Labort = FALSE;
   gboolean Lbackvalue = FALSE;
+  gint Lcont = 1;
   GtkWidget *Lstatusbox = NULL;
   GError *Lerror = NULL;
 
@@ -915,17 +991,21 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   /* barres de progression */
   Lpbtotal = GTK_PROGRESS_BAR(glade_to_hash(Lxml, Ahash, "pb_total"));
   Lpbstep = GTK_PROGRESS_BAR(glade_to_hash(Lxml, Ahash, "pb_step"));
+  /* pour la conversion des fichiers audio et la pulse bar */
+  g_hash_table_insert(Ahash, "progress", Lpbstep);
   Lpbfifo = GTK_PROGRESS_BAR(glade_to_hash(Lxml, Ahash, "pb_fifo"));
   Lpbbuffer = GTK_PROGRESS_BAR(glade_to_hash(Lxml, Ahash, "pb_buffer"));
 
   /* on attache les variables utilisees lors de l'operation */
   g_hash_table_insert(Ahash, "totaldone", &Ltotaldone);
-  g_hash_table_insert(Ahash, "gabort", &Labort);
+  g_hash_table_insert(Ahash, "gabort", &Labort);  /* operation annuler par l'utilisateur ? */
   g_hash_table_insert(Ahash, "pid", &Lpid);
+  g_hash_table_insert(Ahash, "cont", &Lcont);
   g_hash_table_insert(Ahash, "pid2", &Lpid2);
 
   /* bouton annuler l'operation */
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "btncancelburn")), "clicked", G_CALLBACK(abort_gravure), Ahash);
+  g_signal_connect(G_OBJECT(Lwindowburn), "delete_event", GTK_SIGNAL_FUNC(on_deleteevent_gravure), Ahash);
 
   /* lancement de l'operation en elle meme */
   if (g_str_has_prefix(Aaction, "btnburncopy")) {
@@ -933,8 +1013,6 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
 
   } else if (g_str_has_prefix(Aaction, "btnburnaudio")) {
     Lbackvalue = burn_audio(Ahash, &Lerror);
-    /* Awindow1, Lwindow2, LprogressbarTotal, LprogressbarStep, LprogressbarFifo,
-                            LprogressbarBuffer); */
   } else if (g_str_has_prefix(Aaction, "btnburndata")) {
     Lbackvalue = burn_data(Ahash, &Lerror);
   }
@@ -1085,6 +1163,28 @@ void prepare_combobox_graveur(GladeXML *Axml, GHashTable *Ahash, gchar *Abasenam
   }
 }
 
+void manage_combobox_devicebus(GtkComboBox *Acombobox, Tdriveinfo *Adrive)
+{
+  GtkListStore *Lmodel = gtk_list_store_new(2, G_TYPE_INT, G_TYPE_STRING);
+  GtkCellRenderer *Lcellrender = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+  GtkTreeIter Liter;
+  GSList *Lcur;
+  gint i;
+
+  gtk_combo_box_set_model(Acombobox, GTK_TREE_MODEL(Lmodel));
+
+  gtk_cell_layout_clear(GTK_CELL_LAYOUT(Acombobox));
+  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(Acombobox), Lcellrender, TRUE);
+  gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(Acombobox), Lcellrender,
+    "text", 1, NULL);
+  
+  for(Lcur = Adrive->dev, i=0; Lcur; Lcur = g_slist_next(Lcur), i++) {
+    gtk_list_store_append(Lmodel, &Liter);
+    gtk_list_store_set(Lmodel, &Liter, 0, i, 1, (gchar *)Lcur->data, -1);
+    if (i==Adrive->actuperiph) gtk_combo_box_set_active_iter(Acombobox, &Liter);
+  }
+}
+
 #if 0
 void prepare_properties_mediatreeview(GtkTreeView *Atreeview)
 {
@@ -1136,8 +1236,8 @@ void prepare_properties_devicestreeview(GtkTreeView *Atreeview)
 void prepare_listeaudio(GtkTreeView *Atreeaudio)
 {
   GtkTreeSelection *Lselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(Atreeaudio));
-  GtkListStore *Lmodel = gtk_list_store_new(6, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
-                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
+  GtkListStore *Lmodel = gtk_list_store_new(7, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
   GtkCellRenderer *Lcellrender;
   GtkTreeViewColumn *Lcell;
 
@@ -1166,8 +1266,8 @@ void prepare_listeaudio(GtkTreeView *Atreeaudio)
 void prepare_listedata(GtkTreeView *Atreedata)
 {
   GtkTreeSelection *Lselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(Atreedata));
-  GtkTreeStore *Lmodel = gtk_tree_store_new(6, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
-                                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
+  GtkTreeStore *Lmodel = gtk_tree_store_new(7, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+                                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
   GtkTreeIter Liter;
   GtkCellRenderer *Lcellrender;
   GtkTreeViewColumn *Lcell;
@@ -1194,7 +1294,7 @@ void prepare_listedata(GtkTreeView *Atreedata)
 
   /* icone de base dans la liste des fichiers */
   gtk_tree_store_append(GTK_TREE_STORE(Lmodel), &Liter, NULL);
-  gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2, _("New CD"), 3, "", 4, "", 5, 0, -1);
+  gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2, _("New CD"), 3, "", 4, "", 5, "", 6, 0, -1);
 }
 
 /* fenetre proprietes */
@@ -1253,25 +1353,25 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
 
 
   /** onglet "Programmes externes" **/
-  glade_to_hash(Lxml, Lhash, "cdrecord");
-  glade_to_hash(Lxml, Lhash, "cdrecordlbl");
-  glade_to_hash(Lxml, Lhash, "cdrecordpara");
-  
-  glade_to_hash(Lxml, Lhash, "mkisofs");
-  glade_to_hash(Lxml, Lhash, "mkisofslbl");
-  glade_to_hash(Lxml, Lhash, "mkisofspara");
-  
-  glade_to_hash(Lxml, Lhash, "readcd");
-  glade_to_hash(Lxml, Lhash, "readcdlbl");
-  glade_to_hash(Lxml, Lhash, "readcdpara");
-
-  glade_to_hash(Lxml, Lhash, "sox");
-  glade_to_hash(Lxml, Lhash, "soxlbl");
-  glade_to_hash(Lxml, Lhash, "soxpara");
+  glade_to_hash_list(Lxml, Lhash, "cdrecord", "cdrecordlbl", "cdrecordpara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "mkisofs", "mkisofslbl", "mkisofspara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "readcd", "readcdlbl", "readcdpara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "sox", "soxlbl", "soxpara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "growisofs", "growisofslbl", "growisofspara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "dvd+rw-mediainfo", "dvd+rw-mediainfolbl", "dvd+rw-mediainfopara", NULL);
+  glade_to_hash(Lxml, Lhash, "popupdevices");
 
   /** onglet "Lecteurs" **/
   Ltreeview = GTK_TREE_VIEW(glade_to_hash(Lxml, Lhash, "periphdata"));
   prepare_properties_devicestreeview(Ltreeview);
+  g_signal_connect(G_OBJECT(Ltreeview), "button-press-event", G_CALLBACK(gtk_do_eventbuttonpress), Lhash);
+  g_signal_connect(G_OBJECT(Ltreeview), "popup-menu", G_CALLBACK(key_popupmenu_devices), Lhash);
+
+  /* popup sur les peripheriques */
+  g_signal_connect(G_OBJECT(glade_to_hash(Lxml, Lhash, "popupdevices_edit")),
+      "activate", G_CALLBACK(gtk_devices_edit), Lhash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Lxml, Lhash, "popupdevices_remove")),
+      "activate", G_CALLBACK(gtk_devices_remove), Lhash);
 
   g_hash_table_insert(Lhash, "topwindow", Aparent);
   
@@ -1286,7 +1386,11 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
 
   Lbtn = GTK_BUTTON(glade_xml_get_widget(Lxml, "scandevice"));
   g_signal_connect(G_OBJECT(Lbtn), "clicked", G_CALLBACK(cherchelecteur), Lhash);
+
+  Lbtn = GTK_BUTTON(glade_to_hash(Lxml, Lhash, "adddevice"));
+  g_signal_connect(G_OBJECT(Lbtn), "clicked", G_CALLBACK(gtk_devices_add), Lhash);
   
+ 
   return Lhash;
 }
 
