@@ -26,23 +26,111 @@
 
 #include "graveman.h"
 
-Tdrive_info Gldrives[128];
-unsigned int Gnumdrives = 0; 
+GSList *Glistdrives = NULL;
 
-Tdrive_info *findlecteur(gchar *Aname) {
-  gint i;
-  for (i=0; i < Gnumdrives; i++) {
+Tdriveinfo *find_drive(gchar *Aident) {
+  GSList *Lcur, *Lcurdev;
+  Tdriveinfo *Ldrive;
+ 
+  for (Lcur = Glistdrives; Lcur; Lcur = g_slist_next(Lcur)) { 
+    Ldrive = (Tdriveinfo *)Lcur->data;
 
-  _DEB("om compare [%s] et [%s]\n", Aname, Gldrives[i].dev);
-    if (!strcmp(Aname, Gldrives[i].dev)) {
-      _DEB("ici GL vitesse => %d\n", Gldrives[i].vitesse);
-      return &Gldrives[i];
+    for (Lcurdev = Ldrive->dev; Lcurdev; Lcurdev = g_slist_next(Lcurdev)) {
+
+  _DEB("om compare [%s] et [%s]\n", Aident, (gchar *)Lcurdev->data);
+      if (!strcmp(Aident, (gchar *)Lcurdev->data)) {
+        _DEB("ici GL vitesse => %d\n", Ldrive->vitesse);
+        return Ldrive;
+      }
     }
   }
 
   return NULL;
 }
 
+/* ajout d'un lecteur a la liste des lecteurs */
+void append_this_drive(Tdriveinfo *Adrive) {
+  Glistdrives=g_slist_append(Glistdrives, Adrive);
+}
+
+/* liberation de la zone memoire occupe par une structure lecteur */
+void free_this_drive(Tdriveinfo *Adrive) {
+  GSList *Lcur;
+  if (g_slist_length(Adrive->dev)) {
+    for (Lcur = Adrive->dev; Lcur; Lcur = g_slist_next(Lcur)) {
+      g_free((gchar *)Lcur->data);
+    }
+    g_slist_free(Adrive->dev);
+  }
+  if (g_slist_length(Adrive->bus)) {
+    for (Lcur = Adrive->bus; Lcur; Lcur = g_slist_next(Lcur)) {
+      g_free((gchar *)Lcur->data);
+    }
+    g_slist_free(Adrive->bus);
+  }
+
+  g_free(Adrive->name);
+}
+
+void free_drives(gboolean Aremovemanu)
+{
+  GSList *Ltmp = Glistdrives, *Lcurlist;
+  gboolean Ldonotdel;
+  Tdriveinfo *Lcur;
+
+  while (Ltmp) {
+    Lcurlist = Ltmp;
+    Lcur = (Tdriveinfo *)Ltmp->data;
+
+    Ldonotdel = (Lcur->manual == TRUE && Aremovemanu==FALSE);
+
+    Ltmp = g_slist_next(Ltmp);
+
+    if (Ldonotdel == FALSE) {
+      free_this_drive((Tdriveinfo *)Lcurlist->data);
+    
+      Glistdrives = g_slist_delete_link(Glistdrives, Lcurlist);
+    }
+  }
+
+  if (g_slist_length(Glistdrives)==0) Glistdrives = NULL;
+}
+
+void insert_or_update_drive(gchar *Adev, gchar *Amarque, gchar *Amodel, gchar *Aquoi, Tsearchdrive *Adrivedesc)
+{
+  /* on commence par construire l'identifiant */
+  gchar *Lident = g_strdup_printf("%s %s %s", Amarque, Amodel, Aquoi);
+  GSList *Lcur = NULL;
+  Tdriveinfo *Ldrive;
+
+  for (Lcur = Glistdrives; Lcur; Lcur = g_slist_next(Lcur)) {
+    Ldrive = (Tdriveinfo *)Lcur->data;
+
+    if (!strcmp(Ldrive->name, Lident) && strcmp((gchar *)g_slist_last(Ldrive->bus)->data, Adrivedesc->bus)) {
+_DEB("mise a jour du lecteur [%s]\n", Lident);      
+      /* oui ce lecteur existe deja, c'est donc lui qui l'on va mettre a jour */
+      break;
+    }
+  }
+
+  if (!Lcur) {
+    /* le lecteur n'existe pas encore, on l'ajoute a la liste */
+
+    Ldrive = g_malloc0(sizeof(Tdriveinfo));
+    Ldrive->name = Lident;
+
+    Glistdrives = g_slist_append(Glistdrives, Ldrive);
+_DEB("nouveau lecteur [%s]\n", Lident);      
+  } else {
+    g_free(Lident);
+  }
+
+_DEB("le bus en question [%s] = [%s]\n", Adrivedesc->bus, Adev);
+  Ldrive->bus = g_slist_append(Ldrive->bus, g_strdup(Adrivedesc->bus));
+  Ldrive->dev = g_slist_append(Ldrive->dev,
+      g_strdup_printf("%s%s", Adrivedesc->useline, strcmp(Adrivedesc->bus, "IDE") ? Adev : ""));
+}
+
 /* operation de copie */
 gboolean burn_copy(GHashTable *Ahash, GError **Aerror)
 {
@@ -251,11 +339,13 @@ gboolean burn_audio(GHashTable *Ahash, GError **Aerror)
   g_hash_table_insert(Ahash, "gerror", Aerror);  /* pointeur retour des erreurs */
   g_hash_table_insert(Ahash, "tmpdir", &Ltmpdir); /* repertoire temporraire */
 
-  if (!preparetrack(Ahash, Aerror)) return FALSE;
+  Lstatus = preparetrack(Ahash, Aerror);
 
-  Ldone = 1;
+  if (Lstatus == TRUE) {
+    Ldone = 1;
 
-  Lstatus = gravepiste(Ahash, Aerror);
+    Lstatus = gravepiste(Ahash, Aerror);
+  }
 
   if (Ltmpdir) {
     _DEB("on free tmpdir !");
@@ -310,32 +400,22 @@ _DEB("ok fin efface");
   return TRUE;
 }
 
-gboolean is_duplicate_drives(gchar *Abustype, gchar *Adev)
-{
-  gchar Lsearch[64];
-  gint i;
-  gchar *s;
-  gchar Lcmpbuf[64];
-
-  if (strcmp(Abustype, "ATAPI:")) return FALSE;
-
-  g_snprintf(Lsearch, sizeof(Lsearch)-1, "ATA:%s", Adev);
-  if ((s=strchr(Lsearch, ':'))) {
-    while (g_ascii_isdigit(*(++s))==TRUE) *s='?';
+/* retourne le type d'un peripherique */
+void put_devicelabel(Tdriveinfo *Adrive, gchar *Abuf, gint Asizemax) {
+  if (DRIVE_DVDWRITER(Adrive)) {
+    g_strlcpy(Abuf, _("DVD Recorder"), Asizemax);
+  } else if (DRIVE_WRITER(Adrive)) {
+    g_strlcpy(Abuf, _("CD Recorder"), Asizemax);
+  } else if (DRIVE_DVDREADER(Adrive)) {
+    g_strlcpy(Abuf, _("DVD Reader"), Asizemax);
+  } else if (DRIVE_READER(Adrive)) {
+    g_strlcpy(Abuf, _("CD Reader"), Asizemax);
+  } else {
+    g_strlcpy(Abuf, _("Other device"), Asizemax);
   }
-
-  for (i=0; i < Gnumdrives; i++) {
-    g_strlcpy(Lcmpbuf, Gldrives[i].dev, sizeof(Lcmpbuf)-1);
-    if ((s=strchr(Lcmpbuf, ':'))) {
-      while (g_ascii_isdigit(*(++s))) *s='?';
-    }
-
-    if (!strcmp(Lsearch, Lcmpbuf)) return TRUE;
-  }
-
-  return FALSE;
 }
 
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
